ChartInfo class abstract

A class that holds information about a chart, including data tip format and labels for the axes and title.

Annotations
  • @freezed

Constructors

ChartInfo({@Default.new('%s\nX: %x\nY: %y') String dataTipFormat, @Default.new('') String labelBottom, @Default.new('') String labelLeft, @Default.new('') String labelRight, @Default.new('') String labelTop, @Default.new('') String title})
const
factory

Properties

copyWith → $ChartInfoCopyWith<ChartInfo>
Create a copy of ChartInfo with the given fields replaced by the non-null parameter values.
no setterinherited
dataTipFormat String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
labelBottom String
no setterinherited
labelLeft String
no setterinherited
labelRight String
no setterinherited
labelTop String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited