ChartStyle class abstract

A class that defines the style properties for charts.

Annotations
  • @freezed

Constructors

ChartStyle({required double devicePixelRatio, required double fontSize, required double pointRadius, @Default.new(Colors.black) Color borderColor, @Default.new(Colors.white) Color borderColorDark, @Default.new(Colors.white) Color dataTipBackgroundColor, @Default.new(Colors.black) Color dataTipBackgroundColorDark, @Default.new(Colors.grey) Color gridColor, @Default.new(Colors.grey) Color gridColorDark, @Default.new(false) bool invertXAxis, @Default.new(false) bool invertYAxis, @Default.new(2) double lineWidth, @Default.new(false) bool showTicksBottom, @Default.new(false) bool showTicksLeft, @Default.new(false) bool showTicksRight, @Default.new(false) bool showTicksTop, @Default.new(Colors.black) Color textColor, @Default.new(Colors.white) Color textColorDark})
const
factory

Properties

borderColor Color
no setterinherited
borderColorDark Color
no setterinherited
copyWith → $ChartStyleCopyWith<ChartStyle>
Create a copy of ChartStyle with the given fields replaced by the non-null parameter values.
no setterinherited
dataTipBackgroundColor Color
no setterinherited
dataTipBackgroundColorDark Color
no setterinherited
devicePixelRatio double
no setterinherited
fontSize double
no setterinherited
gridColor Color
no setterinherited
gridColorDark Color
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
invertXAxis bool
no setterinherited
invertYAxis bool
no setterinherited
lineWidth double
no setterinherited
pointRadius double
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTicksBottom bool
no setterinherited
showTicksLeft bool
no setterinherited
showTicksRight bool
no setterinherited
showTicksTop bool
no setterinherited
textColor Color
no setterinherited
textColorDark Color
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited