DateTimeChartData class

A chart data class specifically for handling DateTime data series.

Inheritance

Constructors

DateTimeChartData({required KtList<GenericDataSeries<DateTime, double>> dataSeriesList, required GenericTools<DateTime> toolsX, required GenericTools<double> toolsY, required GenericMinMax<DateTime, double> minMax})

Properties

copyWith → $GenericChartDataCopyWith<DateTime, double, GenericChartData<DateTime, double>>
Create a copy of GenericChartData with the given fields replaced by the non-null parameter values.
no setterinherited
dataSeriesList → KtList<GenericDataSeries<DateTime, double>>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
minMax GenericMinMax<DateTime, double>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolsX GenericTools<DateTime>
finalinherited
toolsY GenericTools<double>
finalinherited

Methods

createDoubleChartData() DoubleChartData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

DEBUG → const bool