DateTimeFormatter class

A formatter for DateTime objects that formats them using a specified DateFormat.

Implemented types

Constructors

DateTimeFormatter(DateFormat dateTimeFormat)
const

Properties

dateTimeFormat → DateFormat
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(dynamic value) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited