DateTimeTools class

A class that provides tools for working with DateTime objects,

Inheritance

Constructors

DateTimeTools(GenericFormatter<DateTime> formatter, GenericFormatter<DateTime> dataTipFormatter, {required bool useUtc})

Properties

dataTipFormatter GenericFormatter<DateTime>
finalinherited
formatter GenericFormatter<DateTime>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useUtc bool
final

Methods

format(DateTime value) String
inherited
formatDataTip(DateTime value) String
inherited
getNextDoubleValue(double value) double
override
getNextNiceCustomValue(DateTime value) DateTime
override
getNextNiceCustomValueOrSame(DateTime value) DateTime
override
getPreviousNiceCustomValue(DateTime value) DateTime
override
getPreviousNiceCustomValueOrSame(DateTime value) DateTime
override
mid(DateTime a, DateTime b) DateTime
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCustomValue(double value) DateTime
override
toDoubleValue(DateTime value) double
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited