DoubleChartData class

A specific implementation of GenericChartData for double values.

Inheritance

Constructors

DoubleChartData({required KtList<GenericDataSeries<double, double>> dataSeriesList, required GenericTools<double> toolsX, required GenericTools<double> toolsY, required GenericMinMax<double, double> minMax})

Properties

copyWith → $GenericChartDataCopyWith<double, double, GenericChartData<double, double>>
Create a copy of GenericChartData with the given fields replaced by the non-null parameter values.
no setterinherited
dataSeriesList → KtList<GenericDataSeries<double, double>>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
minMax GenericMinMax<double, double>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolsX GenericTools<double>
finalinherited
toolsY GenericTools<double>
finalinherited

Methods

createDoubleChartData() DoubleChartData
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited