DoubleFormatter class

A formatter for double values that formats them to a specified precision.

Implemented types

Constructors

DoubleFormatter(int precision)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
precision int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(dynamic value) String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited