DoubleTools class

A class that provides specific tools for handling double values in charts.

Inheritance

Constructors

DoubleTools(GenericFormatter<double> formatter, GenericFormatter<double> dataTipFormatter)

Properties

dataTipFormatter GenericFormatter<double>
finalinherited
formatter GenericFormatter<double>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(double value) String
inherited
formatDataTip(double value) String
inherited
getNextDoubleValue(double value) double
override
getNextNiceCustomValue(double value) double
override
getNextNiceCustomValueOrSame(double value) double
override
getPreviousNiceCustomValue(double value) double
override
getPreviousNiceCustomValueOrSame(double value) double
override
mid(double a, double b) double
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCustomValue(double value) double
override
toDoubleValue(double value) double
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited