GenericChartData<TX, TY> class

A generic chart data class that holds a list of data series, tools for X and Y axes, and min/max values.

Implementers
Annotations
  • @freezed

Constructors

GenericChartData({required KtList<GenericDataSeries<TX, TY>> dataSeriesList, required GenericTools<TX> toolsX, required GenericTools<TY> toolsY, required GenericMinMax<TX, TY> minMax})
const

Properties

copyWith → $GenericChartDataCopyWith<TX, TY, GenericChartData<TX, TY>>
Create a copy of GenericChartData with the given fields replaced by the non-null parameter values.
no setterinherited
dataSeriesList → KtList<GenericDataSeries<TX, TY>>
final
hashCode int
The hash code for this object.
no setterinherited
minMax GenericMinMax<TX, TY>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolsX GenericTools<TX>
final
toolsY GenericTools<TY>
final

Methods

createDoubleChartData() DoubleChartData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited