GenericDataSeries<TX, TY> class

A generic data series class that holds a list of points with a specific type for X and Y values.

Annotations
  • @freezed

Constructors

GenericDataSeries(Color color, String label, KtList<GenericPoint<TX, TY>> points)
const

Properties

color Color
final
copyWith → $GenericDataSeriesCopyWith<TX, TY, GenericDataSeries<TX, TY>>
Create a copy of GenericDataSeries with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
label String
final
points → KtList<GenericPoint<TX, TY>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited