GenericPoint<TX, TY> class

A generic point class that can hold any type of x and y coordinates.

Annotations
  • @freezed

Constructors

GenericPoint(TX x, TY y)
const

Properties

copyWith → $GenericPointCopyWith<TX, TY, GenericPoint<TX, TY>>
Create a copy of GenericPoint with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x → TX
final
y → TY
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited