GenericTools<T> class abstract

An abstract class that defines generic tools for formatting and manipulating values of type T.

Implementers

Constructors

GenericTools(GenericFormatter<T> formatter, GenericFormatter<T> dataTipFormatter)
const

Properties

dataTipFormatter GenericFormatter<T>
final
formatter GenericFormatter<T>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(T value) String
formatDataTip(T value) String
getNextDoubleValue(double value) double
getNextNiceCustomValue(T value) → T
getNextNiceCustomValueOrSame(T value) → T
getPreviousNiceCustomValue(T value) → T
getPreviousNiceCustomValueOrSame(T value) → T
mid(T a, T b) → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCustomValue(double value) → T
toDoubleValue(T value) double
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited