ClosestLineInfo class abstract
A class that holds information about the closest point on a line and its index.
- Annotations
-
- @freezed
Constructors
- ClosestLineInfo({required ClosestPointInfo closestPoint, required int lineIndex})
-
constfactory
Properties
- closestPoint → ClosestPointInfo
-
no setterinherited
-
copyWith
→ $ClosestLineInfoCopyWith<
ClosestLineInfo> -
Create a copy of ClosestLineInfo
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineIndex → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited