ClosestPointInfo class abstract
A class that holds information about the closest point on a chart.
- Annotations
-
- @freezed
Constructors
- ClosestPointInfo({required double distance, required int? pointIndex, required Offset position})
-
constfactory
Properties
-
copyWith
→ $ClosestPointInfoCopyWith<
ClosestPointInfo> -
Create a copy of ClosestPointInfo
with the given fields replaced by the non-null parameter values.
no setterinherited
- distance → double
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- pointIndex → int?
-
no setterinherited
- position → Offset
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited