DateTimeMinMax class
A class that represents the minimum and maximum values for DateTime objects.
- Inheritance
-
- Object
- GenericMinMax<
DateTime, double> - DateTimeMinMax
Constructors
- DateTimeMinMax({required DateTime minX, required DateTime maxX, required double minY, required double maxY})
Properties
-
copyWith
→ $GenericMinMaxCopyWith<
DateTime, double, GenericMinMax< DateTime, double> > -
Create a copy of GenericMinMax
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxX → DateTime
-
finalinherited
- maxY → double
-
finalinherited
- minX → DateTime
-
finalinherited
- minY → double
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getHeight(
) → double -
override
-
getWidth(
) → DateTime -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited