DateTimePoint typedef
A point class that represents a point in a 2D space with DateTime as the X value and double as the Y value.
Implementation
typedef DateTimePoint = GenericPoint<DateTime, double>;
A point class that represents a point in a 2D space with DateTime as the X value and double as the Y value.
typedef DateTimePoint = GenericPoint<DateTime, double>;