DoubleMinMax class
A class that represents the minimum and maximum values for double values.
- Inheritance
-
- Object
- GenericMinMax<
double, double> - DoubleMinMax
Constructors
- DoubleMinMax({required double minX, required double maxX, required double minY, required double maxY})
Properties
-
copyWith
→ $GenericMinMaxCopyWith<
double, double, GenericMinMax< double, double> > -
Create a copy of GenericMinMax
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxX → double
-
finalinherited
- maxY → double
-
finalinherited
- minX → double
-
finalinherited
- minY → double
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getHeight(
) → double -
override
-
getWidth(
) → double -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited