DoublePoint typedef
A point class that represents a point in a 2D space with DateTime as the X value and double as the Y value.
Implementation
typedef DoublePoint = GenericPoint<double, double>;
A point class that represents a point in a 2D space with DateTime as the X value and double as the Y value.
typedef DoublePoint = GenericPoint<double, double>;