GenericMinMax<TX, TY> class
A generic class that holds minimum and maximum values for two types, TX and TY.
- Implementers
- Annotations
-
- @freezed
Constructors
- GenericMinMax({required TX minX, required TX maxX, required TY minY, required TY maxY})
-
const
Properties
-
copyWith
→ $GenericMinMaxCopyWith<
TX, TY, GenericMinMax< TX, TY> > -
Create a copy of GenericMinMax
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxX → TX
-
final
- maxY → TY
-
final
- minX → TX
-
final
- minY → TY
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getHeight(
) → TY -
getWidth(
) → TX -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited